from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x99\x08\x00\x00\x00\x00\x00\x18\xdf\x39\xa3\x54\x47\xe1\xba\xeb\xde\xcd\x85\xdd\x05\x78\xfb\x60\x00\x00\x00\x00\x00\x00\x00\x00\x80\x3d\xe6\x2d\xd0\x0e\xf9\xa5\x03\x82\xed\x3a\x17\x2c\x4e\xc8\xd6\xc7\x6d\xcf\x0b\x02\x5b\x41\x45\x3b\xee\xfc\x06\xe0\x1c\xd5\xc5\x47\xba\xc4\x97\xfd\xe6\x11\x5b\xd4\x6f\x7d\xaf\xb6\xf7\x7f\xe7\x9e\x4b\xd7\x86\xd2\x16\xc4\x65\xe4\x01\x4c\x08\xf1\xd3\x61\x41\x95\x89\xea\x01\x42\x77\xc9\x2a\x0c\xf8\x4b\xd3\xb0\xa0\xc2\x0a\x07\x08\xbc\x06\xe8\xac\xd0\xd7\xe7\x0a\x9a\x20\xdb\x40\xbe\xc3\xba\x0d\xbd\xf4\xa4\xb2\x64\x68\xcd\x2d\xb8\x6d\xb7\xc1\x66\xf9\x0b\x4a\xbf\x17\x0e\xdc\x28\xa2\x0b\xe2\x4c\xe4\x6a\xc5\xc7\x01\xf2\x10\xd0\x62\x4c\x3e\x82\x8a\x87\x85\xa5\x6a\x2b\xed\xf3\xd9\xc1\x49\xc4\x20\xc7\xc1\x3c\x2a\x3e\x5b\x1b\xde\xba\x0c\xa3\x7e\xb7\xb3\x7b\x35\x5b\x91\x18\xfa\x98\x0f\x9e\x42\x50\x13\x14\xa5\xb7\x11\x98\x4a\xef\xc8\xde\x75\x32\xcb\x32\xc4\x97\xa3\x98\x2f\xf7\x38\x71\xa8\xfa\x6d\x59\xf6\x59\xcf\x49\x13\x20\x0a\x3b\x19\x88\x47\x16\xfb\x29\xf7\x48\xfb\x5f\xa0\xc1\x06\x84\x4c\x8e\x2d\xd5\x86\x5a\x87\x25\x6d\xc1\x45\x95\x65\x99\xb5\x28\xbd\xfa\x52\x61\xc1\x10\xa0\xfc\x45\x24\x70\xf0\x75\x0e\x39\x65\x21\x6a\x6d\x06\xc3\xee\x18\x5b\x45\xf0\x65\x61\x2e\x25\x0d\x14\x1b\x03\x16\x91\x7b\x36\x37\xc9\xeb\xbc\xf0\xc6\x20\xd1\x61\xcd\xde\x25\x17\xee\xe6\xe8\x80\xed\xf6\x9f\x9a\x81\x5e\x69\xb6\xc2\xca\x58\xc9\x58\x98\x15\x31\xb1\xb0\xbb\xfa\x27\x2d\x6e\x90\xd7\xea\x53\xf8\x1f\xd0\x20\xbd\x1b\xb2\xf7\x5d\x39\xad\x2d\x6f\x0c\x26\x96\x17\x88\x0d\xf3\xf3\x36\xe3\xe4\x62\x54\xb1\xb1\xfe\x32\x96\xec\x18\x20\x90\xcb\x95\x12\xc6\xd3\x31\x5e\x8d\xd6\xad\x55\xc4\x54\x4b\xa8\x3c\x7c\x42\xdd\xbc\x4b\xcf\x84\x3d\xdd\x5f\x5c\xd1\xde\xc5\xca\x3f\x00\x7b\xa3\x4f\xd4\x32\x15\x60\x44\xf2\xf7\xad\xf1\x09\xfc\x10\x94\x20\x79\x27\x42\x58\xc6\x74\x38\xf1\xbc\xe9\x0f\x30\xb1\xb6\x48\xce\xee\x0b\x29\xc1\xdc\x51\x81\xe9\x3b\xe0\x0f\xfc\xf0\xd6\x45\x03\x42\xc7\xba\x3f\x37\x7d\x95\x5f\xb4\x0c\xd2\x07\x4a\x19\xfd\xf1\x39\x31\x19\x93\x19\xfa\x21\x01\xae\x73\x7d\xf0\x83\xd9\x84\xbc\x6a\x3b\x93\xe8\xc0\xad\xb1\x18\x32\xd2\xcf\xc5\x84\xc3\x2f\x5a\x92\x1a\xa7\x6b\x32\x40\x0e\x84\xa5\xf5\xdc\x24\x7f\xbe\xe5\xe3\xda\x0b\xe5\x44\xb7\x86\x5e\x48\x4e\x0c\xa7\x8b\x98\xfc\xbd\x9e\x75\x63\xfe\xe4\x4f\xf8\xe4\x1a\x4d\x6b\xfb\xc2\xe4\xb4\x0c\x74\x46\xf2\x52\x7f\x2b\x7e\x6e\x93\x6d\xbc\x72\x71\x97\x80\x12\x9a\x6d\x0f\x81\x3c\x5b\x08\xdf\xbf\xae\x68\x27\x99\x47\xf5\x97\x26\x6b\x16\x56\x78\xd7\x0c\x8b\xbb\x95\x8b\xd9\x38\xe6\xe0\x91\xf1\x0f\xb4\x6d\xd7\xe8\xb1\xd1\xd2\x4c\x21\xcf\x68\x13\xec\x66\xeb\x67\xee\xcf\xd1\x95\xa9\xce\xf8\xa6\x4b\xfb\x8e\x22\xfe\x8a\xd7\x83\xc8\x4a\x98\x88\x66\xce\x60\x2d\x56\xee\xd0\xb7\x15\x5a\x36\xf1\xd5\x0c\xbd\x6b\xc4\xbc\xe1\xb8\x43\x65\xbb\x8e\xf7\x63\xfd\x1b\x90\x4a\x3c\xaf\x65\xaa\x92\x67\x67\x37\xa0\x43\xb5\xa1\x0d\x1e\xa9\xb3\xde\x65\x30\xff\x04\x38\xc2\x66\xd7\x53\x3d\x5b\xfb\x1a\x83\x4d\x7b\xcb\xe6\x82\x4c\xbf\xfa\x1c\x6a\x66\x7f\x5f\x65\x6e\x8c\x87\x6c\x36\x10\xe2\x29\xf8\xa4\xb9\xa3\x82\x62\x5e\xf6\x47\xf4\x98\x0e\xef\x7e\x4b\x36\xeb\x96\x3e\x99\xda\xd6\xc5\x6b\xc4\x7e\xea\xbc\xaf\x97\x2f\x33\xac\xb8\x06\xff\xb9\xc7\x4c\xb0\x84\xfa\xa0\x22\x81\xcc\x1c\x4b\x87\xd8\x0b\x5d\x00\xb1\x71\x3b\xe1\xd1\x70\x84\x44\x5d\x8b\x8c\x31\xf8\xd4\x89\xc9\x9d\xbe\x19\xb6\xf2\x72\x84\x9d\x91\x0b\xb4\x6f\x58\x9f\xef\x5c\x76\x01\x26\x0b\xb3\x92\x2c\x0a\x58\x8f\x0b\x0f\xa0\x38\x8a\x67\x82\x60\x3d\xeb\x05\xfa\x88\x28\x45\x46\xf3\xbe\xf6\xff\xfb\xe3\x67\x7a\x1b\xbc\x4c\x76\xe2\x07\x1a\x34\x41\x8b\x02\x81\x7e\x77\x51\x97\xc7\xd1\x30\xfb\x52\x40\x31\x3b\x27\xda\xa3\x6e\xa2\xb1\x71\xb4\x36\x81\xdd\x35\xe1\xf1\xeb\x4a\x26\x8a\xf4\x8c\xea\x53\xee\xd8\xf3\xff\x78\xfe\xbc\x7e\x9a\x5b\x4f\x2a\xfe\x45\xc4\x94\xfe\xbb\xd4\x3e\x00\xcd\x78\x7c\x55\xd3\x37\x49\x78\xdd\x5d\xb9\xa2\x63\x8f\xf1\x8a\x67\xcb\x42\x24\xa0\x16\x37\xc4\x2f\x2f\x82\x4f\xf4\xf3\x60\x23\x65\xdd\x2a\xa8\x9c\x04\xff\x8c\x11\xb4\x64\x5b\x96\x36\xf7\x19\x9b\xc3\xc4\x61\x68\xa6\x5e\xb7\x54\x86\x07\xbc\x5e\xeb\x30\xfc\x87\x67\x22\x79\x6e\x92\x5e\x2a\x3c\x4a\x0b\xc4\x66\x52\x5f\xf9\xe5\x99\x3b\xd9\x65\x4a\x79\x75\xcf\xd2\xf4\x3c\xb8\x55\x94\x9a\xbb\x7a\xfb\xd3\xa6\x56\x8b\x5d\x41\x45\xb1\xe6\x56\x1c\xad\xb8\x39\x69\x96\xc5\x69\x1b\xb1\xde\x77\xca\x9e\x1a\xc1\xd0\xe8\xa5\x87\xd5\x16\xe4\x14\x36\xa4\x28\xe3\x40\x12\x0d\xec\xc3\x9b\xc5\xb7\xcf\x21\xd0\x7e\xa3\x4a\x3c\x64\x36\xde\x3f\x2a\xe1\xb3\x24\x2a\xad\xa5\x03\x57\xa4\x18\x33\x00\x17\x84\xa3\x86\x97\x9a\x6a\x06\x0e\x4a\xb2\xcd\xb3\xa2\x6c\x79\xae\x1c\xdb\xe7\xc5\x90\x61\xdb\x0f\x36\x23\x73\xe6\x69\x1a\xca\x03\x13\x61\xe1\x2a\xd2\xbf\xd7\xbf\x51\x7e\x34\xff\x28\x5c\x4e\xad\x92\x9e\x98\xf0\xe8\x5a\x65\x39\x72\x21\x51\x0a\x9a\xdf\x60\x73\x7d\x7d\xc7\x04\x47\xf4\xb8\xed\x25\xf3\x76\x37\x54\x15\xcb\x57\xd6\x69\x25\xb4\xa9\x7a\x0a\x3f\x99\xda\xcc\xab\xe3\xfc\x54\xd3\xd2\x2c\x7d\x7f\xa6\x93\x0e\x52\xb6\x48\xff\x97\x1a\x96\xe5\x7e\x98\x7e\xad\xa4\xd3\x58\x14\x5c\xc7\x97\x13\x66\x05\x83\xdf\x13\x38\xed\x57\xb7\x0b\xc0\x85\xbd\xb5\x72\xf6\x03\xba\xf1\xff\x98\xc2\xea\x3c\x57\xbe\x5b\x7d\x45\xef\xc9\xf6\x33\x46\x4b\xdd\x9a\x78\xab\x56\x0d\x4e\xca\x2d\x8c\x91\xec\x9c\x72\xcb\xe5\xda\x9c\x69\xf0\xdc\x97\x55\x98\xb9\x8d\x6b\x6f\x6b\x92\x75\xcb\xc8\x8f\xcd\x43\xbc\x05\x4b\xb4\xfb\x87\xe3\xf0\xfe\xd3\x47\x8f\xcb\xc3\x4e\x44\x59\xdd\xba\x92\x65\xfc\xe0\x3d\x5c\x77\xf8\x3e\xa6\x95\x21\xb4\x1e\xee\xd4\xb1\xa4\xb6\xaa\x4c\xba\x74\xba\x2d\x47\xa7\x08\x7b\xf2\x6a\x71\x5b\xa9\x65\x92\xd1\x20\x8a\x2e\x56\x08\x49\x1f\x93\x11\x1f\xf8\x81\x68\xee\x4c\x95\xbf\xa3\x5c\x52\xd1\x36\xdd\xe3\xab\x02\x81\xf2\xd1\xff\x30\x2e\x26\x14\xdb\xb0\xca\xda\xf4\x1d\x6a\xa3\xeb\x5c\x37\x10\xf7\xa7\xf4\x9b\x01\x4d\xc3\x7f\x3f\xd5\x02\x17\x0b\xe0\xf9\xc5\xdf\xfc\xa3\x07\x9f\xb5\xff\x16\xda\x1d\x6b\x88\x44\x9c\xe3\xca\x48\x3e\x0a\xba\xab\xaf\x10\xcc\x58\x33\x98\xe8\xc3\xd0\x6b\x0b\x05\xec\xa4\x47\x99\x8a\x70\x60\xd0\x01\x47\xe2\xbe\x3d\x51\xb9\xa0\x0d\xa6\x21\x61\xe4\x52\xc3\xee\x4e\x4f\x8e\xa0\x96\x68\xe1\xdb\xe9\xea\x65\x2e\x1a\xa1\x35\x99\xed\xda\x17\xc5\xe6\x29\x88\x45\xa2\x02\x7f\x42\x7b\x30\xd3\xba\x9c\xd0\x14\xc0\x40\x3b\x75\xc4\xba\xc7\x12\x76\xc8\x22\x86\x69\x3d\xd9\x83\x4e\xcf\x9c\x5f\x10\xed\xcb\x58\x76\xa9\x3d\x9f\xa1\x71\xc7\xb7\xbf\x60\x9b\xea\xc1\xc1\x73\x85\x43\xc7\x83\xec\xfe\xfa\x15\xde\xe4\x88\xdb\x92\xe5\xb4\x0d\xa7\x7b\x65\x48\xdd\x17\xc4\xcc\x1a\xdd\xca\x41\xf0\xd3\x87\xa2\x83\x99\xf9\xdb\x59\x1b\x1e\xe7\x4c\xc5\x59\x82\x14\x60\xd6\xbd\x4a\xd2\xa9\xd9\x2e\xf8\x4e\xda\x60\x31\xee\xdb\xe8\x01\x1a\xb0\xd7\xdd\x4f\xb0\x0f\xe4\xe0\x58\xef\xef\xd1\x89\xa5\x44\xf9\x5c\x44\xa5\x35\xbd\x96\x7b\x74\x88\x93\xbe\xe2\x5c\xb7\x7c\x5a\x1c\x27\xf9\x4e\x64\x0f\x02\xef\x04\x40\x8c\x60\x49\x38\xfb\x22\x60\x8e\xf5\x7f\x09\xd6\x0e\x3e\xca\x0c\xdf\xa8\xe0\x54\x30\x69\x32\x78\x90\xb6\x8d\xbb\xa2\x5d\xd8\x7b\xc2\x5f\xeb\x9d\x29\xca\xd4\xdf\xd0\x9a\xe5\x60\x5b\x5d\x3a\xf5\x68\xd9\xa5\xa0\x4e\x9d\x5d\xbe\x27\xf3\x1f\xa5\xd1\x35\xdb\x68\x20\xcc\x09\xfe\x67\x43\x57\x80\xf6\x58\x1d\x91\x9a\x29\xe6\xd6\xe2\x04\x08\x0f\xc2\xfb\x62\x66\x85\x3e\x77\xdc\xf5\x09\x1d\x56\xd1\x73\xb5\x2a\xbf\x99\x12\x35\x09\xfd\x19\x99\xc0\xe2\x82\x02\xb1\x98\x35\xab\x32\xdd\x9f\x21\xb6\x28\xed\x35\xd3\x86\x89\x5d\x0e\x33\xfd\x76\x7c\x1b\x2c\x57\x8d\x97\x72\x66\x4e\xdb\x6c\x9d\x25\xcb\x99\xae\xd6\x87\xf5\xb0\x06\x6e\x0a\x4a\x04\xa1\x6c\x73\x30\x49\x2c\x48\x4f\x28\xd5\xdb\xbe\xd1\x26\x71\x17\x25\x1e\x49\xea\xf9\xf6\xe1\x37\xfe\x22\x00\xa7\xc5\x04\x14\xfb\x17\x22\x27\xb7\xca\xb6\x47\xb8\xba\x3a\xac\x42\x4d\x07\xe8\xb8\x97\x70\x27\x44\x27\xfb\x10\x32\xa6\x72\xa1\x87\xe7\x56\xc6\x7a\x60\xab\xd7\xb9\xba\x66\x21\x50\x20\x95\xc2\x7d\xfc\xee\x15\xfb\x53\x09\x3b\x3b\x1a\xe0\x02\xb1\xfd\x93\xf9\xee\x68\xf1\x82\x99\xe7\xdf\xa5\x02\xed\xef\x8f\xd8\x13\xc8\x60\x29\x1a\x66\x9c\x0d\xa4\x3e\xbe\xdc\x17\xb7\x95\xca\xdd\x6d\xf6\xb2\x47\x1c\x85\xf2\x5e\xe4\x10\xe1\x73\x6c\xd6\x3e\x22\x76\xdc\xb4\xdc\xa1\x85\xb8\xb9\x37\x4b\x20\x64\x70\x42\x1f\x0c\x07\x21\x77\x3f\xc0\x59\xad\xd4\xea\x04\xb8\x21\x96\x6c\xe1\x01\x5a\x8a\x72\x1a\xca\x25\x01\x0a\x20\xad\x41\x73\x52\x68\x1d\x51\x2b\xce\xe4\xae\xcb\x99\x62\x70\x68\xd2\xac\x4a\xd4\x06\xb2\x38\xc5\x73\x74\x00\x16\xa5\x7c\x02\x54\xaf\xaf\x70\x7d\x77\xe9\x62\x81\x72\x07\x11\x00\x92\xa8\xea\x2c\x94\x1f\x20\x1b\xcf\x76\x9a\xb1\x11\xee\xfb\x3e\xcd\x6c\xf9\xbd\x37\xe2\x0b\x47\x26\x35\x03\xcc\xd2\x20\x20\xa3\xdf\x65\xbf\xdc\x25\xd0\xa1\x1f\xb4\xc8\xd5\x4b\x04\xa4\x26\xa3\x85\x93\xaf\xe0\x71\x59\xdc\x94\x74\xa8\xd7\xe9\xf7\xcf\x9c\x01\xb1\xcb\x6d\x8b\xe7\x91\x3a\x26\xf5\x3c\xb8\x7e\x41\x0e\x10\x56\x8b\x76\xd1\x01\x88\x62\x62\x41\x95\xe3\x3a\x99\x0f\x9a\xfe\x12\xb0\x45\xb0\xaa\x86\xdd\x94\x01\x1a\x4a\x1c\x5f\x07\x1a\x7d\x90\xca\x30\x58\x41\xc8\x01\x53\xea\x09\xcd\x1e\x72\xe9\x69\x0b\xbb\x63\x21\x71\x09\x9c\xb2\xf7\xc5\x45\x50\x68\xfa\xb3\xc9\x91\x01\x49\xcf\x99\x09\x32\x22\x4d\x1e\x21\x1c\x5e\x03\xa5\xbb\x25\xcb\x52\x81\x92\x09\x3d\x3f\xec\xa9\x63\x3f\xfc\xa2\x2e\x85\x7f\x26\xf6\x56\x38\x37\xce\xc4\x61\x49\xd1\x19\xce\x70\x2f\x31\x16\xe7\x04\x19\x24\xec\xf2\xa2\x3e\x01\x9a\xe3\x51\xa1\xda\x64\x80\x0c\x37\xe8\x42\xdc\xeb\x9c\xd4\xbc\xaf', 2)

# cleanup
del pyarmor_runtime

